@@ -108,7 +108,7 @@ struct _CalendarWindowPrivate {
 #endif /* HAVE_LIBECAL */
 };
 
-G_DEFINE_TYPE (CalendarWindow, calendar_window, GTK_TYPE_WINDOW);
+G_DEFINE_TYPE (CalendarWindow, calendar_window, GTK_TYPE_WINDOW)
 
 enum {
 	PROP_0,
@@ -385,9 +385,12 @@ is_appointment (GtkTreeModel *model,
 
 	gtk_tree_model_get (model, iter, APPOINTMENT_COLUMN_URI, &uri, -1);
 	if (uri)
-		return (strcmp (uri, "file") == 0 ||
-			strcmp (uri, "webcal") == 0 ||
-			strcmp (uri, "caldav") == 0);
+		return (g_ascii_strcasecmp (uri, "file")   == 0 ||
+			g_ascii_strcasecmp (uri, "webcal") == 0 ||
+			g_ascii_strcasecmp (uri, "caldav") == 0 ||
+			g_ascii_strcasecmp (uri, "exchange")  == 0 ||
+			g_ascii_strcasecmp (uri, "groupwise") == 0 ||
+			g_ascii_strcasecmp (uri, "google") == 0);
 	return FALSE;
 }
 
@@ -400,7 +403,7 @@ is_birthday (GtkTreeModel *model,
 
 	gtk_tree_model_get (model, iter, APPOINTMENT_COLUMN_URI, &uri, -1);
 	if (uri)
-		return (strcmp (uri, "contacts") == 0);
+		return (g_ascii_strcasecmp (uri, "contacts") == 0);
 	return FALSE;
 }
 
@@ -413,7 +416,7 @@ is_weather (GtkTreeModel *model,
 
 	gtk_tree_model_get (model, iter, APPOINTMENT_COLUMN_URI, &uri, -1);
 	if (uri)
-		return (strcmp (uri, "weather") == 0);
+		return (g_ascii_strcasecmp (uri, "weather") == 0);
 	return FALSE;
 }
 
@@ -519,14 +522,18 @@ set_renderer_pixbuf_color_by_column (GtkCellRenderer *renderer,
 {
         char      *color_string;
         GdkPixbuf *pixbuf = NULL;
-        guint32    color;
+        GdkColor   color;
 
         gtk_tree_model_get (model, iter, column_number, &color_string, -1);
 
-        if (color_string) {
-                sscanf (color_string, "%06x", &color);
+        if (color_string && gdk_color_parse (color_string, &color)) {
                 pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 16, 16);
-                gdk_pixbuf_fill (pixbuf, color << 8);
+                /* GdkColor has 16 bits per color, gdk_pixbuf only uses 8 bits
+                 * per color. So just drop the least significant parts */
+                gdk_pixbuf_fill (pixbuf,
+				 (color.red   & 0xff00) << 16 |
+				 (color.green & 0xff00) << 8  | 
+				 (color.blue  & 0xff00));
 
                 g_object_set (renderer, "visible", pixbuf != NULL, "pixbuf", pixbuf, NULL);
 
@@ -586,9 +593,9 @@ set_renderer_pixbuf_pixmap_for_bday (GtkCellRenderer *renderer,
 	 * pas-id-41112AF900000003-birthday
 	 * ...
 	 */
-	if (g_strrstr (type, "birthday") != 0)
+	if (g_strrstr (type, "birthday") != NULL)
 		path = CLOCK_EDS_ICONDIR G_DIR_SEPARATOR_S "category_birthday_16.png";
-	else if (g_strrstr (type, "anniversary") != 0)
+	else if (g_strrstr (type, "anniversary") != NULL)
 		path = CLOCK_EDS_ICONDIR G_DIR_SEPARATOR_S "category_gifts_16.png";
 	else
 		path = CLOCK_EDS_ICONDIR G_DIR_SEPARATOR_S "category_miscellaneous_16.png";
@@ -1158,24 +1165,31 @@ calendar_day_activated (GtkCalendar    *calendar,
 	unsigned int  day;
 	unsigned int  month;
 	unsigned int  year;
-	time_t        now;
-	struct tm     utc_tm;
-	struct tm     local_tm;
+	time_t        date;
+	struct tm     utc_date_tm;
+	struct tm     local_date_tm = { 0, };
 	char         *argument;
 
 	gtk_calendar_get_date (calendar, &year, &month, &day);
 
-	time (&now);
-	gmtime_r (&now, &utc_tm);
-	localtime_r (&now, &local_tm);
+	local_date_tm.tm_mday  = (int) day;
+	local_date_tm.tm_mon   = (int) month;
+	local_date_tm.tm_year  = (int) year - 1900;
+	local_date_tm.tm_isdst = -1;
+
+	/* convert the local date picked in the calendar to broken-down UTC */
+	date = mktime (&local_date_tm);
+	gmtime_r (&date, &utc_date_tm);
 
 	/* FIXME: once bug 409200 is fixed, we'll have to make this hh:mm:ss
 	 * instead of hhmmss */
 	argument = g_strdup_printf ("calendar:///?startdate="
 				    "%.4d%.2d%.2dT%.2d%.2d%.2dZ",
-				    year, month + 1, day,
-				    12 + utc_tm.tm_hour - local_tm.tm_hour,
-				    0  + utc_tm.tm_min  - local_tm.tm_min,
+				    utc_date_tm.tm_year + 1900,
+				    utc_date_tm.tm_mon + 1,
+				    utc_date_tm.tm_mday,
+				    utc_date_tm.tm_hour,
+				    utc_date_tm.tm_min,
 				    0);
 
 	clock_launch_evolution (calwin, argument);
