@@ -22,13 +22,21 @@
  *	Vincent Untz <vuntz@gnome.org>
  */
 
-#ifndef PANEL_EXT_H
-#define PANEL_EXT_H
+#ifndef PANEL_GLIB_H
+#define PANEL_GLIB_H
+
+#include <glib.h>
 
 G_BEGIN_DECLS
 
 #define PANEL_GLIB_STR_EMPTY(x) ((x) == NULL || (x)[0] == '\0')
 
+char       *panel_g_lookup_in_data_dirs         (const char *basename);
+char       *panel_g_lookup_in_applications_dirs (const char *basename);
+
+const char *panel_g_utf8_strstrcase             (const char *haystack,
+						 const char *needle);
+
 G_END_DECLS
 
 #endif /* PANEL_GLIB_H */
