@@ -25,13 +25,13 @@
 #ifndef __PANEL_STOCK_ICONS_H__
 #define __PANEL_STOCK_ICONS_H__
 
-#include <glib/gmacros.h>
-#include <gtk/gtkenums.h>
+#include <glib.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
 /* themeable size - "panel-menu" */
-#define PANEL_DEFAULT_MENU_ICON_SIZE 	22
+#define PANEL_DEFAULT_MENU_ICON_SIZE 	24
 
 /* stock icons */
 #define PANEL_STOCK_FORCE_QUIT          "gnome-panel-force-quit"
